# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': '.'}

packages = \
['hifis_surveyval']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.0,<8',
 'matplotlib>=3.2.0',
 'numpy>=1.18.1',
 'pandas>=1.0.1',
 'pyyaml>=5.3.1']

entry_points = \
{'console_scripts': ['hifis-surveyval = hifis_surveyval.cli:cli']}

setup_kwargs = {
    'name': 'hifis-surveyval',
    'version': '0.2.0rc2',
    'description': 'This project is used to develop analysis scripts for the HIFIS Software survey.',
    'long_description': '<!--\nhifis-surveyval\nFramework to help developing analysis scripts for the HIFIS Software survey.\n\nSPDX-FileCopyrightText: 2021 HIFIS Software <support@hifis.net>\n\nSPDX-License-Identifier: GPL-3.0-or-later\n\nThis program is free software: you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation, either version 3 of the License, or\n(at your option) any later version.\n\nThis program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program. If not, see <http://www.gnu.org/licenses/>.\n-->\n\n# HIFIS-Surveyval\n\nThis project is used to develop analysis scripts for the HIFIS Software survey.\n\n## Table of Content\n\n* [Installation](#installation)\n* [Getting Started](#getting-started)\n* [Development](#development)\n* [Start Analysis from Command-Line-Interface](#start-analysis-from-command-line-interface)\n* [Contribute with Own Analysis Scripts](#contribute-with-own-analysis-scripts)\n* [Resources](#resources)\n* [License](#license)\n\n## Getting Started\n\nThe project\'s documentation contains a section to help you\n[get started](TODO) as a developer or\nuser of the analysis scripts.\n\n## Installation\nTo install the package locally, you can either use [poetry](https://python-poetry.org/)\nor `pip`.\n\n### Using pip\n\n```shell\npip install hifis-surveyval\n```\n\nAfter the installation, you can use the tool from the command line with `hifis-surveyval --help`.\n\n### Using poetry\n\n```shell\ngit clone $PATH_TO_THIS_PROJECT\ncd hifis-surveyval\npoetry install --no-dev\n```\n\nAfter the installation, you can use the tool from the command line with `poetry run hifis-surveyval --help`\nThe following documentation references the pip installation.\nYou can use the same commands with a poetry installation, if you refix you commands with `poetry run COMMAND`.\n\n## Development\nIf you want to actively contribute changes to the project, you are required to\nalso install the development packages.\nTherefore, use below extended installation options.\n\n```shell\npoetry install\n```\n\nThis installs some packages that are required for performing quality checks.\nUsually they are also performed via GitLab CI, but can also be executed locally.\n\nIt is common practice to run some checks locally before pushing them online.\nTherefore, execute below commands:\n```console\n$ # Order your imports\n$ isort -rc .\n$ make lint\n```\n\n## Start Analysis from Command-Line-Interface\n\nThe survey analysis package is a program to be executed on the\nCommand-Line-Interface (CLI).\n\n### Quick Start Example: Run Analysis\n\nIn order to run the survey analysis you need to copy the data-CSV-file \nfor example from the \n[wiki page](https://gitlab.hzdr.de/hifis/survey-about-current-development-practice/-/wikis/home) \nof the associated GitLab project \n[Survey about current Development Practice](https://gitlab.hzdr.de/hifis/survey-about-current-development-practice)\ninto a central location like the [data/](data/) sub-folder of your local python \nproject and tell the program the path to that data file.\n\nNow you can do the following to start the survey analysis from the CLI:\n\n```shell script\nhifis-surveyval analyze data/<data_file_name>.csv\n```\n\nIt tells the program that you would like to do the analysis,\nwhere to find the analysis scripts, the _metadata_-file as well as \nthe _data_-file to be taken into account for the analysis.\n\n**Caution:** \nDepending on the Operating System used an issue with the file \nencoding might occur.\nThere might be data-CSV-files around which are encoded with `UTF-8-BOM`\nwhich causes errors when read in on Windows OS.\nIn this case you need to change the encoding to `UTF-8` before running\nthe survey analysis.\n\n### Flags\n\nThe program accepts a couple of flags:\n\n1. Help flag\n2. Verbosity flag\n3. Scripts flag\n4. Names flag\n5. Output Folder flag\n6. Output Format flag\n\n#### Help flag\n\nCalling the program with the _help_-flag is the first thing to do\nwhen being encountered with this program.\nIt outputs a so-called _Usage_-message to the CLI:\n\n```shell script\n$ hifis-surveyval --help\nUsage: hifis-surveyval [OPTIONS] COMMAND [ARGS]...\n\n  Analyze a given CSV file with a set of independent python scripts.\n\nOptions:\n  -v, --verbose             Enable verbose output. Increase verbosity by\n                            setting this option up to 3 times.  [default: 0]\n\n  -s, --scripts TEXT        Select the folder containing analysis scripts.\n                            [default: scripts]\n\n  -n, --names TEXT          Optionally select the specific script names\n                            contained in the scripts folder (while omitting\n                            file endings) which should be executed.\n\n  -o, --output-folder TEXT  Select the folder to put the generated output like\n                            plots into.  [default: output]\n\n  -f, --output-format TEXT  Designate output format. Supported values are:\n                            SCREEN, PDF, PNG, SVG.  [default: screen]\n\n  --help                    Show this message and exit.\n\nCommands:\n  analyze  Read the given files into global data and metadata objects.\n  version  Get the library version.\n```\n\n#### Verbosity flag\n\nThe _verbosity_-flag can be provided in order to specify the verbosity\nof the output to the CLI.\nThis flag is called `--verbose` or `-v` for short:\n\n```shell script\nhifis-surveyval --verbose <COMMAND>\n```\n```shell script\nhifis-surveyval -v <COMMAND>\n```\n\nThe verbosity of the output can be increased even more \nby duplicating the flag `--verbose` or `-v` up to two times:\n\n```shell script\nhifis-surveyval --verbose --verbose --verbose <COMMAND>\n```\n```shell script\nhifis-surveyval -vvv <COMMAND>\n```\n\n#### Scripts flag\n\nBeside verbosity there is a _scripts_-flag called `--scripts` or \n`-s` for short:\n\n```shell script\nhifis-surveyval --scripts "scripts" <COMMAND>\n```\n```shell script\nhifis-surveyval -s "scripts" <COMMAND>\n```\n\nThis will tell the program in which folder to look for the actual \nanalysis scripts.\nIn case the _scripts_-flag is omitted it defaults to sub-folder `scripts/`.\n\n#### Names flag\n\nThere is also a _names_-flag called `--names` or `-n` for short:\n\n```shell script\nhifis-surveyval --names "example_script_1" --names "example_script_2" <COMMAND>\n```\n```shell script\nhifis-surveyval -n "example_script_1" -n "example_script_2" <COMMAND>\n```\n\nThis will tell the program which scripts in the scripts folder to execute.\nIn case the _names_-flag is omitted it defaults to all scripts in the\nscripts folder.\n\n#### Output Folder flag\n\nThe _output-folder_-flag called `--output-folder` or `-o` for short \nis another option:\n\n```shell script\nhifis-surveyval --output-folder "output" <COMMAND>\n```\n```shell script\nhifis-surveyval -o "output" <COMMAND>\n```\n\nThis will tell the program in which folder to put the generated output \nlike plots into.\nIn case the _output-folder_-flag is omitted it defaults to sub-folder \n`output/`.\n\n#### Output format flag\n\nThe user is also able to let the application know in which output format the\ndiagrams should be generated during the analysis. \nFor this purpose there is a flag called `--output-format` or `-f` for short.\nAllowed values to this flag are the following:\n* SCREEN\n* PDF\n* PNG\n* SVG\n\nOn the CLI the actual call looks like this:\n\n```shell script\nhifis-surveyval --output-format PNG <COMMAND>\n```\n```shell script\nhifis-surveyval -f PNG <COMMAND>\n```\n\n### Commands\n\nThere are two different commands implemented which come with different\nflags and parameters:\n\n1. Command _version_\n2. Command _analyze_\n\n#### Command _version_\n \nThe `version` command outputs the version number of \nthis CLI-program like so:\n\n```shell script\nhifis-surveyval version\n0.0.1\n```\n\n#### Command _analyze_\n\nThe more interesting command is the `analyze` command\nwhich comes with a _metadata_-flag `--metadata` or `-m` for short and \na _data_-parameter.\nIn case the _metadata_-flag is omitted it assumes the following\npath to the metadata file: \n`metadata/HIFIS_Software_Survey_2020_Questions.yml`.\nThe _data_-parameter can _not_ be omitted and need to be given explicitly\nin order to be able to start the analysis.\nThis is an example of how to do the analysis:\n\n```shell script\nhifis-surveyval analyze data/<data_file_name>.csv\n```\n\n## Contribute with Own Analysis Scripts\n\n### Essential Criteria for Developing Own Analysis Scripts\n\nAs you might have read in the previous sections the actual analysis scripts \nreside in a specific folder called `scripts/`.\nAll scripts in that folder will be automatically discovered by the package \n`hifis-surveyval` when running the analysis.\nIn order that the program recognizes the scripts in that folder as\nanalysis scripts they need to fulfil the following two criteria:\n\n1. The filename need to end on `.py`.\n2. The file need to contain a function called `run` without any parameters.\n\n```python\n"""\nA dummy script for testing the function dispatch\n\n.. currentmodule:: hifis_surveyval.scripts.dummy\n.. moduleauthor:: HIFIS Software <software@hifis.net>\n"""\n\ndef run():\n    print("Example Script")\n```\n\nIf both criteria are satisfied the program will execute the `run`-functions\nof the analysis scripts in an arbitrary sequence.\n\n### File-System Structure of Core Component\n\n```shell script\n$ tree hifis_surveyval/\nhifis_surveyval/\n├── answer.py\n├── cli.py\n├── data.py\n├── dispatch.py\n├── globals.py\n├── metadata.py\n├── question.py\n├── settings.py\n└── version.py\n```\n\n### Files and Classes Explained\n\n**ToDo**: This section need to be extended to all files and classes\nfound in package `hifis_surveyval`.\n\n#### Classes to Represent Questions\n\nFile `question.py` contains the following classes:\n- `AbstractQuestion`: Abstract class providing properties of a question \nlike `id` and `text`.\n- `Question`: Non-abstract class inheriting from abstract-base-class\n`AbstractQuestion`. It represents a question with associated answers.\n- `QuestionCollection`: Non-abstract class inheriting from abstract-base-class\n`AbstractQuestion`. It represents a question with associated sub-questions.\n\n#### Class to Represent Answers\n\nFile `answer.py` contains class `Answer`.\nThis class provides properties of an answer like `id` and `text`.\n\n## Resources\n\nBelow are some handy resource links.\n\n* [Project Documentation](TODO)\n* [Click](https://click.palletsprojects.com/en/7.x) is a Python package for creating beautiful command line interfaces in a composable way with as little code as necessary.\n* [Sphinx](http://www.sphinx-doc.org/en/master/) is a tool that makes it easy to create intelligent and beautiful documentation, written by Geog Brandl and licnsed under the BSD license.\n* [pytest](https://docs.pytest.org/en/latest/) helps you write better programs.\n* [GNU Make](https://www.gnu.org/software/make/) is a tool which controls the generation of executables and other non-source files of a program from the program\'s source files.\n\n\n## License\n\nCopyright © 2021 HIFIS Software <support@hifis.net>\n\nThis work is licensed under the following license(s):\n* Everything else is licensed under [GPL-3.0-or-later](LICENSES/GPL-3.0-or-later.txt)\n\nPlease see the individual files for more accurate information.\n\n> **Hint:** We provided the copyright and license information in accordance to the [REUSE Specification 3.0](https://reuse.software/spec/).',
    'author': 'HIFIS Software',
    'author_email': 'software@hifis.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<3.10',
}


setup(**setup_kwargs)
